@@ -1,11 +1,10 @@
 package MooseX::BuildArgs;
 {
-  $MooseX::BuildArgs::VERSION = '0.03';
+  $MooseX::BuildArgs::VERSION = '0.04';
 }
 use Moose ();
 use Moose::Exporter;
 
-
 =head1 NAME
 
 MooseX::BuildArgs - Save the original constructor arguments for later use.
@@ -18,11 +17,7 @@ Create a class that uses this module:
     use Moose;
     use MooseX::BuildArgs;
     has foo => ( is=>'ro', isa=>'Str' );
-
-Then whenever an instance of this class is created all arguments to the
-constructor are saved in the build_args attribute:
-
-    use MyClass;
+    
     my $object = MyClass->new( foo => 32 );
     print $object->build_args->{foo};
 
@@ -33,7 +28,7 @@ defaults, and coercion take affect.  This module provides a build_args hashref a
 for all instances of the consuming class.  The build_args attribute contains all arguments
 that were passed to the constructor.
 
-A typical case for this module would be for creating a clone of an object, so you could
+A contrived case for this module would be for creating a clone of an object, so you could
 duplicate an object with the following code:
 
     my $obj1 = MyClass->new( foo => 32 );
@@ -42,49 +37,13 @@ duplicate an object with the following code:
 
 =cut
 
-Moose::Exporter->setup_import_methods();
-
-sub init_meta {
-    shift;
-    my %args = @_;
-
-    Moose->init_meta( %args );
-
-    my $class = $args{for_class};
-
-    Moose::Util::MetaRole::apply_base_class_roles(
-        for_class => $class,
-        roles => [ 'MooseX::BuildArgs::Role' ],
-    );
-
-    return $class->meta();
-}
-
-{
-    package MooseX::BuildArgs::Role;
-{
-  $MooseX::BuildArgs::Role::VERSION = '0.03';
-}
-    use Moose::Role;
-
-    has build_args => (
-        is       => 'ro',
-        isa      => 'HashRef',
-        required => 1,
-        init_arg => '_build_args',
-    );
-
-    around BUILDARGS => sub{
-        my $orig = shift;
-        my $self = shift;
-
-        my $args = $self->$orig( @_ );
-
-        $args->{_build_args} = { %$args };
-
-        return $args;
-    };
-}
+Moose::Exporter->setup_import_methods(
+    role_metaroles => {
+        application_to_class => ['MooseX::BuildArgs::Meta::ToClass'],
+        application_to_role  => ['MooseX::BuildArgs::Meta::ToRole'],
+    },
+    base_class_roles => ['MooseX::BuildArgs::Meta::Object'],
+);
 
 1;
 __END__
